# SURE: SUccinct REpresentation of cells
 SURE implements a discrete latent state model with normalizing flow encoder for exact estimation of cellular populations. 


## Installation
1. Create a virtual environment
```bash
conda create -n SURE python=3.10 scipy numpy pandas scikit-learn && conda activate SURE
```

2. Install [PyTorch](https://pytorch.org/get-started/locally/) following the official instruction. 
```bash
pip3 install torch torchvision --index-url https://download.pytorch.org/whl/cu126
```

3. Install SURE
```bash
pip3 install SURE-tools
```



